#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_UNARY_MINUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_UNARY_MINUS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/unary_minus.hpp>

#endif
